@@ -37,11 +37,10 @@ var(a::fqPolyRepRelPowerSeriesRing) = a.S
 max_precision(R::fqPolyRepRelPowerSeriesRing) = R.prec_max
 
 function normalise(a::fqPolyRepRelPowerSeriesRingElem, len::Int)
+  len <= 0 && return len
   ctx = base_ring(a)
-  if len > 0
-    c = base_ring(a)()
-    @ccall libflint.fq_nmod_poly_get_coeff(c::Ref{fqPolyRepFieldElem}, a::Ref{fqPolyRepRelPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{fqPolyRepField})::Nothing
-  end
+  c = base_ring(a)()
+  @ccall libflint.fq_nmod_poly_get_coeff(c::Ref{fqPolyRepFieldElem}, a::Ref{fqPolyRepRelPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{fqPolyRepField})::Nothing
   while len > 0 && iszero(c)
     len -= 1
     if len > 0
