@@ -14,9 +14,7 @@ parent_type(::Type{FpFieldElem}) = FpField
 
 elem_type(::Type{FpField}) = FpFieldElem
 
-base_ring_type(::Type{FpField}) = typeof(Union{})
-
-base_ring(a::FpField) = Union{}
+base_ring_type(::Type{FpField}) = Union{}
 
 parent(a::FpFieldElem) = a.parent
 
