@@ -595,9 +595,7 @@ for (etype, rtype, mtype, brtype) in (
     end
 
     function (a::($rtype))(b::Vector{($mtype)}, len::Int, prec::Int)
-      if length(b) > 0
-        (base_ring(a) != parent(b[1])) && error("Wrong parents")
-      end
+      @req all(parent(e) == base_ring(a) for e in b) "parents do not match"
       z = ($etype)(a.n, b, len, prec)
       z.parent = a
       return z
